@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -39,26 +39,27 @@
 // Forward declarations.
 //
 
-void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5);
+void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6);
 
 /**
  * Branches the programme flow, depending on the criterion flag.
  *
  * Expected parametres:
  * - criterion (required): the flag specifying which of the two models to execute
- * - true (required): the logic knowledge model to be executed if the condition is true
- * - false (required): the logic knowledge model to be executed if the condition is false
+ * - true (optional): the logic knowledge model to be executed if the condition is true
+ * - false (optional): the logic knowledge model to be executed if the condition is false
  *
  * Constraints:
  *
  * @param p0 the parametres data
  * @param p1 the parametres count
  * @param p2 the knowledge memory part
- * @param p3 the internal memory data
- * @param p4 the signal memory item
- * @param p5 the shutdown flag
+ * @param p3 the stack memory item
+ * @param p4 the internal memory data
+ * @param p5 the signal memory item
+ * @param p6 the shutdown flag
  */
-void apply_branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
+void apply_branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n\n");
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply branch.");
@@ -77,11 +78,11 @@ void apply_branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
     void* cmd = *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Get criterion part.
-    get_part_name((void*) &c, p0, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &c, p0, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) CRITERION_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get true part.
-    get_part_name((void*) &t, p0, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &t, p0, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) TRUE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get false part.
-    get_part_name((void*) &f, p0, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &f, p0, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME, (void*) FALSE_BRANCH_FLOW_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
 
     // Get criterion part model item.
     copy_array_forward((void*) &cm, c, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
@@ -112,14 +113,14 @@ fwprintf(stdout, L"TEST branch *cmd: %i\n", *((int*) cmd));
 //?? fwprintf(stdout, L"TEST branch true: %i\n", r);
 
         // The criterion is true. Handle true model.
-        handle(t, p3, p2, p4, (void*) &x, p5);
+        handle(t, p4, p2, p3, p5, (void*) &x, p6);
 
     } else {
 
 //?? fwprintf(stdout, L"TEST branch false: %i\n", r);
 
         // The criterion is false. Handle false model.
-        handle(f, p3, p2, p4, (void*) &x, p5);
+        handle(f, p4, p2, p3, p5, (void*) &x, p6);
     }
 //?? fwprintf(stdout, L"TEST branch END: %i\n", r);
 }
