@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -52,11 +52,12 @@
  *
  * Constraints:
  *
- * @param p0 the parametres array (signal/ operation part properties with pointers referencing parts)
- * @param p1 the parametres array count
+ * @param p0 the parametres data
+ * @param p1 the parametres count
  * @param p2 the knowledge memory part
+ * @param p3 the stack memory item
  */
-void apply_insert(void* p0, void* p1, void* p2) {
+void apply_insert(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply insert.");
 
@@ -96,17 +97,17 @@ void apply_insert(void* p0, void* p1, void* p2) {
     void* simd = *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Get destination part.
-    get_name_array((void*) &d, p0, (void*) DESTINATION_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) DESTINATION_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &d, p0, (void*) DESTINATION_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) DESTINATION_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get source part.
-    get_name_array((void*) &s, p0, (void*) SOURCE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) SOURCE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &s, p0, (void*) SOURCE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) SOURCE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get type part.
-    get_name_array((void*) &a, p0, (void*) TYPE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) TYPE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &a, p0, (void*) TYPE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) TYPE_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get count part.
-    get_name_array((void*) &c, p0, (void*) COUNT_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) COUNT_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &c, p0, (void*) COUNT_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) COUNT_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get destination index part.
-    get_name_array((void*) &di, p0, (void*) DESTINATION_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) DESTINATION_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &di, p0, (void*) DESTINATION_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) DESTINATION_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get source index part.
-    get_name_array((void*) &si, p0, (void*) SOURCE_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) SOURCE_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1);
+    get_part_name((void*) &si, p0, (void*) SOURCE_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME, (void*) SOURCE_INDEX_INSERT_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
 
     // Get source part model.
     copy_array_forward((void*) &sm, s, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
