@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -51,8 +51,9 @@
  * @param p0 the parametres data
  * @param p1 the parametres count
  * @param p2 the knowledge memory part
+ * @param p3 the stack memory item
  */
-void apply_remove(void* p0, void* p1, void* p2) {
+void apply_remove(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply remove.");
 
@@ -80,11 +81,11 @@ void apply_remove(void* p0, void* p1, void* p2) {
     void* imd = *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Get part.
-    get_part_name((void*) &p, p0, (void*) PART_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) PART_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &p, p0, (void*) PART_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) PART_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get count part.
-    get_part_name((void*) &c, p0, (void*) COUNT_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) COUNT_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &c, p0, (void*) COUNT_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) COUNT_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
     // Get index part.
-    get_part_name((void*) &i, p0, (void*) INDEX_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) INDEX_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2);
+    get_part_name((void*) &i, p0, (void*) INDEX_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME, (void*) INDEX_REMOVE_MODIFICATION_LOGIC_CYBOL_NAME_COUNT, p1, p2, p3);
 
     // Get part type, model.
     copy_array_forward((void*) &pa, p, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TYPE_PART_STATE_CYBOI_NAME);
