@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -44,8 +44,7 @@
  *
  * Disk Operating System (DOS) Code page 850.
  */
-static wchar_t DOS_850_CYBOL_ENCODING_ARRAY[] = {L'd', L'o', L's', L'-', L'8', L'5', L'0'};
-static wchar_t* DOS_850_CYBOL_ENCODING = DOS_850_CYBOL_ENCODING_ARRAY;
+static wchar_t* DOS_850_CYBOL_ENCODING = L"dos-850";
 static int* DOS_850_CYBOL_ENCODING_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* DOS_CYBOL_ENCODING_CONSTANT_SOURCE */
