@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -121,112 +121,201 @@ static int* DOUBLE_CAST_LOGIC_CYBOI_FORMAT = NUMBER_1202_INTEGER_STATE_CYBOI_MOD
 /** The integer cast logic cyboi format. */
 static int* INTEGER_CAST_LOGIC_CYBOI_FORMAT = NUMBER_1203_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+//
+// command
+//
+
+/** The archive command logic cyboi format. */
+static int* ARCHIVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1300_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The copy command logic cyboi format. */
+static int* COPY_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1301_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The echo command logic cyboi format. */
+static int* ECHO_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1302_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The list-directory-contents command logic cyboi format. */
+static int* LIST_DIRECTORY_CONTENTS_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1303_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The move command logic cyboi format. */
+static int* MOVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1304_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The remove command logic cyboi format. */
+static int* REMOVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1305_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The tape archiver command logic cyboi format. */
+static int* TAPE_ARCHIVER_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1306_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The change-permission command logic cyboi format. */
+static int* CHANGE_PERMISSION_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1307_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The word count command logic cyboi format. */
+static int* WORD_COUNT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1308_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The create folder command logic cyboi format. */
+static int* CREATE_FOLDER_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1309_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The ping command logic cyboi format. */
+static int* PING_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1310_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The grep command logic cyboi format. */
+static int* GREP_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1311_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The traceroute command logic cyboi format. */
+static int* TRACEROUTE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1312_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The diff command logic cyboi format. */
+static int* DIFF_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1313_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The sort command logic cyboi format. */
+static int* SORT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1314_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The clear command logic cyboi format. */
+static int* CLEAR_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1315_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The help command logic cyboi format. */
+static int* HELP_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1316_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The config network command logic cyboi format. */
+static int* CONFIG_NETWORK_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1317_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The date command logic cyboi format. */
+static int* DATE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1318_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The list tasks command logic cyboi format. */
+static int* LIST_TASKS_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1319_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The change directory command logic cyboi format. */
+static int* CHANGE_DIRECTORY_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1320_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The kill process command logic cyboi format. */
+static int* KILL_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1321_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The compare files command logic cyboi format. */
+static int* COMPARE_FILES_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1322_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The disk free command logic cyboi format. */
+static int* DISK_FREE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1323_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The find command command logic cyboi format. */
+static int* FIND_COMMAND_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1324_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The display content command logic cyboi format. */
+static int* DISPLAY_CONTENT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1325_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The find file command logic cyboi format. */
+static int* FIND_FILE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1326_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The sleep command logic cyboi format. */
+static int* DELAY_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1327_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The spellcheck command logic cyboi format. */
+static int* SPELLCHECK_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1328_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The memory free command logic cyboi format. */
+static int* MEMORY_FREE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1329_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The who am i command logic cyboi format. */
+static int* WHO_AM_I_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1330_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The who command logic cyboi format. */
+static int* WHO_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1331_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The top command logic cyboi format. */
+static int* TOP_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1332_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The ifconfig command logic cyboi format. */
+static int* IFCONFIG_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1333_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The id command logic cyboi format. */
+static int* ID_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1334_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The hostname command logic cyboi format. */
+static int* HOSTNAME_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1335_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The userlog command logic cyboi format. */
+static int* USERLOG_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1336_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The touch command logic cyboi format. */
+static int* TOUCH_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1337_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The ifup command logic cyboi format. */
+static int* IFUP_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1338_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The disk usage command logic cyboi format. */
+static int* DISK_USAGE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1339_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The list open files command logic cyboi format. */
+static int* LIST_OPEN_FILES_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1340_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The pwd command logic cyboi format. */
+static int* PWD_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1341_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The system messages command logic cyboi format. */
+static int* SYSTEM_MESSAGES_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1342_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The netstat command logic cyboi format. */
+static int* NETSTAT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1343_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+
 //
 // communicate
 //
 
 /** The receive communicate logic cyboi format. */
-static int* RECEIVE_COMMUNICATE_LOGIC_CYBOI_FORMAT = NUMBER_1300_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* RECEIVE_COMMUNICATE_LOGIC_CYBOI_FORMAT = NUMBER_1400_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The send communicate logic cyboi format. */
-static int* SEND_COMMUNICATE_LOGIC_CYBOI_FORMAT = NUMBER_1301_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SEND_COMMUNICATE_LOGIC_CYBOI_FORMAT = NUMBER_1401_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // compare
 //
 
 /** The equal compare logic cyboi format. */
-static int* EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1400_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1500_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The greater compare logic cyboi format. */
-static int* GREATER_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1401_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* GREATER_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1501_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The greater-or-equal compare logic cyboi format. */
-static int* GREATER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1402_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* GREATER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1502_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The smaller compare logic cyboi format. */
-static int* SMALLER_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1403_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SMALLER_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1503_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The smaller-or-equal compare logic cyboi format. */
-static int* SMALLER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1404_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SMALLER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1504_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The unequal compare logic cyboi format. */
-static int* UNEQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1405_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* UNEQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1505_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // contain
 //
 
 /** The both contain logic cyboi format. */
-static int* BOTH_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1450_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* BOTH_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1550_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The left contain logic cyboi format. */
-static int* LEFT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1451_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* LEFT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1551_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The none contain logic cyboi format. */
-static int* NONE_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1452_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* NONE_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1552_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The right contain logic cyboi format. */
-static int* RIGHT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1453_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* RIGHT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1553_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // convert
 //
 
 /** The decode convert logic cyboi format. */
-static int* DECODE_CONVERT_LOGIC_CYBOI_FORMAT = NUMBER_1500_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* DECODE_CONVERT_LOGIC_CYBOI_FORMAT = NUMBER_1600_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The encode convert logic cyboi format. */
-static int* ENCODE_CONVERT_LOGIC_CYBOI_FORMAT = NUMBER_1501_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* ENCODE_CONVERT_LOGIC_CYBOI_FORMAT = NUMBER_1601_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-//
-// command
-//
-
-/** The archive command logic cyboi format. */
-static int* ARCHIVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1600_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The copy command logic cyboi format. */
-static int* COPY_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1601_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The echo command logic cyboi format. */
-static int* ECHO_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1602_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The list-directory-contents command logic cyboi format. */
-static int* LIST_DIRECTORY_CONTENTS_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1603_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The move command logic cyboi format. */
-static int* MOVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1604_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The remove command logic cyboi format. */
-static int* REMOVE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1605_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The tape archiver command logic cyboi format. */
-static int* TAPE_ARCHIVER_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1606_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The change-permission command logic cyboi format. */
-static int* CHANGE_PERMISSION_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1607_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The word count command logic cyboi format. */
-static int* WORD_COUNT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1608_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The create folder command logic cyboi format. */
-static int* CREATE_FOLDER_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1609_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The ping command logic cyboi format. */
-static int* PING_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1610_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The grep command logic cyboi format. */
-static int* GREP_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1611_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The traceroute command logic cyboi format. */
-static int* TRACEROUTE_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1612_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The diff command logic cyboi format. */
-static int* DIFF_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1613_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The sort command logic cyboi format. */
-static int* SORT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1614_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // flow
@@ -395,5 +484,15 @@ static int* SECOND_SLEEP_RUN_LOGIC_CYBOI_FORMAT = NUMBER_2502_INTEGER_STATE_CYBO
 /** The current time logic cyboi format. */
 static int* CURRENT_TIME_LOGIC_CYBOI_FORMAT = NUMBER_2550_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+//
+// sort
+//
+
+/** The sort/quick logic cybol format. **/
+static int* QUICK_SORT_LOGIC_CYBOI_FORMAT = NUMBER_2600_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The sort/bubble logic cybol format. **/
+static int* BUBBLE_SORT_LOGIC_CYBOI_FORMAT = NUMBER_2601_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /* LOGIC_CYBOI_FORMAT_CONSTANT_SOURCE */
 #endif
