@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -61,8 +61,7 @@
  *
  * This is a CYBOL extension.
  */
-static wchar_t RUN_LOGIC_CYBOL_FORMAT_ARRAY[] = {L'r', L'u', L'n', L'/', L'r', L'u', L'n'};
-static wchar_t* RUN_LOGIC_CYBOL_FORMAT = RUN_LOGIC_CYBOL_FORMAT_ARRAY;
+static wchar_t* RUN_LOGIC_CYBOL_FORMAT = L"run/run";
 static int* RUN_LOGIC_CYBOL_FORMAT_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -75,8 +74,7 @@ static int* RUN_LOGIC_CYBOL_FORMAT_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_AR
  *
  * This is a CYBOL extension.
  */
-static wchar_t NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT_ARRAY[] = {L'r', L'u', L'n', L'/', L's', L'l', L'e', L'e', L'p', L'-', L'n', L'a', L'n', L'o'};
-static wchar_t* NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT = NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT_ARRAY;
+static wchar_t* NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT = L"run/sleep-nano";
 static int* NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT_COUNT = NUMBER_14_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -89,8 +87,7 @@ static int* NANO_SLEEP_RUN_LOGIC_CYBOL_FORMAT_COUNT = NUMBER_14_INTEGER_STATE_CY
  *
  * This is a CYBOL extension.
  */
-static wchar_t SECOND_SLEEP_RUN_LOGIC_CYBOL_FORMAT_ARRAY[] = {L'r', L'u', L'n', L'/', L's', L'l', L'e', L'e', L'p', L'-', L's', L'e', L'c', L'o', L'n', L'd'};
-static wchar_t* SECOND_SLEEP_RUN_LOGIC_CYBOL_FORMAT = SECOND_SLEEP_RUN_LOGIC_CYBOL_FORMAT_ARRAY;
+static wchar_t* SECOND_SLEEP_RUN_LOGIC_CYBOL_FORMAT = L"run/sleep-second";
 static int* SECOND_SLEEP_RUN_LOGIC_CYBOL_FORMAT_COUNT = NUMBER_16_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* RUN_LOGIC_CYBOL_FORMAT_CONSTANT_SOURCE */
