@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Franziska Wehner>
  */
@@ -28,6 +28,7 @@
 #define APPLICATION_VND_STATE_CYBOL_FORMAT_CONSTANT_SOURCE
 
 #include <stddef.h>
+
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 //
@@ -53,13 +54,12 @@
 //
 
 /**
- * The application/vnd.ms-excel state cybol type.
+ * The application/vnd.ms-excel state cybol format.
  *
  * Microsoft Excel files.
  * Suffixes: xls, xla
  */
-static wchar_t VND_MS_EXCEL_APPLICATION_STATE_CYBOL_FORMAT_ARRAY[] = {L'a', L'p', L'p', L'l', L'i', L'c', L'a', L't', L'i', L'o', L'n', L'/', L'v', L'n', L'd', L'.', L'm', L's', L'-', L'e', L'x', L'c', L'e', L'l'};
-static wchar_t* VND_MS_EXCEL_APPLICATION_STATE_CYBOL_FORMAT = VND_MS_EXCEL_APPLICATION_STATE_CYBOL_FORMAT_ARRAY;
+static wchar_t* VND_MS_EXCEL_APPLICATION_STATE_CYBOL_FORMAT = L"application/vnd.ms-excel";
 static int* VND_MS_EXCEL_APPLICATION_STATE_CYBOL_FORMAT_COUNT = NUMBER_24_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /*??
