@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,6 +27,7 @@
 #define BLUETOOTH_STATE_CYBOL_FORMAT_CONSTANT_SOURCE
 
 #include <stddef.h>
+
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 //
@@ -35,10 +36,9 @@
 //
 
 /**
- * The bluetooth/synchronisation-profile state cybol type.
+ * The bluetooth/synchronisation-profile state cybol format.
  */
-static wchar_t SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOL_FORMAT_ARRAY[] = {L'b', L'l', L'u', L'e', L't', L'o', L'o', L't', L'h', L'/', L's', L'y', L'n', L'c', L'h', L'r', L'o', L'n', L'i', L'z', L'a', L't', L'i', L'o', L'n', L'-', L'p', L'r', L'o', L'f', L'i', L'l', L'e'};
-static wchar_t* SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOL_FORMAT = SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOL_FORMAT_ARRAY;
+static wchar_t* SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOL_FORMAT = L"bluetooth/synchronisation-profile";
 static int* SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOL_FORMAT_COUNT = NUMBER_33_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* BLUETOOTH_STATE_CYBOL_FORMAT_CONSTANT_SOURCE */
