@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,6 +27,7 @@
 #define FONTS_STATE_CYBOL_FORMAT_CONSTANT_SOURCE
 
 #include <stddef.h>
+
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 //
@@ -35,10 +36,9 @@
 //
 
 /**
- * The fonts/package state cybol type.
+ * The fonts/package state cybol format.
  */
-static wchar_t PACKAGE_FONTS_STATE_CYBOL_FORMAT_ARRAY[] = {L'f', L'o', L'n', L't', L's', L'/', L'p', L'a', L'c', L'k', L'a', L'g', L'e'};
-static wchar_t* PACKAGE_FONTS_STATE_CYBOL_FORMAT = PACKAGE_FONTS_STATE_CYBOL_FORMAT_ARRAY;
+static wchar_t* PACKAGE_FONTS_STATE_CYBOL_FORMAT = L"fonts/package";
 static int* PACKAGE_FONTS_STATE_CYBOL_FORMAT_COUNT = NUMBER_13_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* FONTS_STATE_CYBOL_FORMAT_CONSTANT_SOURCE */
