@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,6 +27,7 @@
 #define MEDIA_STATE_CYBOL_FORMAT_CONSTANT_SOURCE
 
 #include <stddef.h>
+
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 //
@@ -35,10 +36,9 @@
 //
 
 /**
- * The media/vcd state cybol type.
+ * The media/vcd state cybol format.
  */
-static wchar_t VCD_MEDIA_STATE_CYBOL_FORMAT_ARRAY[] = {L'm', L'e', L'd', L'i', L'a', L'/', L'v', L'c', L'd'};
-static wchar_t* VCD_MEDIA_STATE_CYBOL_FORMAT = VCD_MEDIA_STATE_CYBOL_FORMAT_ARRAY;
+static wchar_t* VCD_MEDIA_STATE_CYBOL_FORMAT = L"media/vcd";
 static int* VCD_MEDIA_STATE_CYBOL_FORMAT_COUNT = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* MEDIA_STATE_CYBOL_FORMAT_CONSTANT_SOURCE */
