@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -85,6 +85,55 @@
 /** The synchronisation-profile bluetooth state cyboi format. */
 //?? static int* SYNCHRONISATION_PROFILE_BLUETOOTH_STATE_CYBOI_FORMAT = NUMBER_150_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+//
+// chronology
+//
+
+/** The buddhist chronology state cyboi language. */
+static int* BUDDHIST_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_160_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The coptic chronology state cyboi language. */
+static int* COPTIC_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_161_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The ethiopic chronology state cyboi language. */
+static int* ETHIOPIC_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_162_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The gregorian-julian chronology state cyboi language. */
+static int* GREGORIAN_JULIAN_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_163_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The gregorian chronology state cyboi language. */
+static int* GREGORIAN_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_164_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The islamic chronology state cyboi language. */
+static int* ISLAMIC_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_165_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The iso chronology state cyboi language. */
+static int* ISO_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_166_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The julian date (jd) chronology state cyboi language. */
+static int* JD_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_167_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The julian chronology state cyboi language. */
+static int* JULIAN_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_168_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The modified julian date (mjd) chronology state cyboi language. */
+static int* MJD_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_169_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The posix (unix) chronology state cyboi language. */
+static int* POSIX_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_170_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The international atomic time (tai) chronology state cyboi language. */
+static int* TAI_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_171_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The international time (ti) chronology state cyboi language. */
+static int* TI_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_172_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The truncated julian date (tjd) chronology state cyboi language. */
+static int* TJD_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_173_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The coordinated universal time (utc) chronology state cyboi language. */
+static int* UTC_CHRONOLOGY_STATE_CYBOI_LANGUAGE = NUMBER_174_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 //
 // image
 //
