@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -71,11 +71,12 @@
  *
  * @param p0 the internal memory data
  * @param p1 the knowledge memory part
- * @param p2 the signal memory item
- * @param p3 the signal memory sleep time
- * @param p4 the shutdown flag
+ * @param p2 the stack memory item
+ * @param p3 the signal memory item
+ * @param p4 the signal memory sleep time
+ * @param p5 the shutdown flag
  */
-void check_signal(void* p0, void* p1, void* p2, void* p3, void* p4) {
+void check_signal(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n");
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Check signal.");
@@ -94,7 +95,7 @@ void check_signal(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
     // Receive signal.
     // It suffices to hand over: destination signal, signal memory item, signal memory index, channel.
-    receive_data(s, *NULL_POINTER_STATE_CYBOI_MODEL, p2, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &i, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) SIGNAL_CYBOI_CHANNEL);
+    receive_data(s, *NULL_POINTER_STATE_CYBOI_MODEL, p3, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &i, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) SIGNAL_CYBOI_CHANNEL);
 
     // Get signal item data.
     // CAUTION! Retrieve data ONLY AFTER having called desired functions!
@@ -104,19 +105,21 @@ void check_signal(void* p0, void* p1, void* p2, void* p3, void* p4) {
     // since it returns an array, but not the contained element.
     get_item_metadata((void*) &sd, s, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
 
+//?? fwprintf(stdout, L"TEST check signal sd: %i\n", sd);
+
     if (sd != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         // A signal was found and has to be handled.
         // Handling a signal has higher priority than checking for new interrupt requests.
 
-        check_found(sd, p0, p1, p2, (void*) &i, p4);
+        check_found(sd, p0, p1, p2, p3, (void*) &i, p5);
 
     } else {
 
         // No signal is available in the signal memory.
         // Query interrupt flags for requests.
 
-        check_empty(p0, p2, p3);
+        check_empty(p0, p3, p4);
     }
 
     // Deallocate signal item.
