@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -52,11 +52,12 @@
  * @param p0 the signal part
  * @param p1 the internal memory data
  * @param p2 the knowledge memory part
- * @param p3 the signal memory item
- * @param p4 the direct execution flag
- * @param p5 the shutdown flag
+ * @param p3 the stack memory item
+ * @param p4 the signal memory item
+ * @param p5 the direct execution flag
+ * @param p6 the shutdown flag
  */
-void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
+void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n");
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Handle signal.");
@@ -97,31 +98,27 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
     copy_array_forward((void*) &pd, p, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
     copy_array_forward((void*) &pc, p, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
 
-/*??
-//?? TEST BEGIN
-static int TEST_COUNTER = 0;
-TEST_COUNTER++;
-fwprintf(stdout, L"TEST handle TEST_COUNTER: %i\n", TEST_COUNTER);
-void* TEST_ITEM = *NULL_POINTER_STATE_CYBOI_MODEL;
-void* TEST_ITEM_DATA = *NULL_POINTER_STATE_CYBOI_MODEL;
-void* TEST_ITEM_COUNT = *NULL_POINTER_STATE_CYBOI_MODEL;
-allocate_item((void*) &TEST_ITEM, (void*) NUMBER_20_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
-append_item_element(TEST_ITEM, (void*) L"TEST/test_", (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE, (void*) NUMBER_10_INTEGER_STATE_CYBOI_MODEL, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME);
-serialise_cybol_integer(TEST_ITEM, (void*) &TEST_COUNTER, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
-copy_array_forward((void*) &TEST_ITEM_DATA, TEST_ITEM, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-copy_array_forward((void*) &TEST_ITEM_COUNT, TEST_ITEM, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
-test_part_as_model_diagram(TEST_ITEM_DATA, p2);
-deallocate_item((void*) &TEST_ITEM, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
-//?? TEST END
-*/
+// //?? TEST BEGIN
+// static int TEST_COUNTER = 0;
+// TEST_COUNTER++;
+// fwprintf(stdout, L"TEST handle TEST_COUNTER: %i\n", TEST_COUNTER);
+// void* TEST_ITEM = *NULL_POINTER_STATE_CYBOI_MODEL;
+// void* TEST_ITEM_DATA = *NULL_POINTER_STATE_CYBOI_MODEL;
+// void* TEST_ITEM_COUNT = *NULL_POINTER_STATE_CYBOI_MODEL;
+// allocate_item((void*) &TEST_ITEM, (void*) NUMBER_20_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+// append_item_element(TEST_ITEM, (void*) L"TEST/test_", (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE, (void*) NUMBER_10_INTEGER_STATE_CYBOI_MODEL, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME);
+// serialise_cybol_integer(TEST_ITEM, (void*) &TEST_COUNTER, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
+// copy_array_forward((void*) &TEST_ITEM_DATA, TEST_ITEM, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
+// copy_array_forward((void*) &TEST_ITEM_COUNT, TEST_ITEM, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
+// test_part_as_model_diagram(TEST_ITEM_DATA, p2);
+// deallocate_item((void*) &TEST_ITEM, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+// //?? TEST END
 
-/*??
-if (fd != *NULL_POINTER_STATE_CYBOI_MODEL) {
-fwprintf(stdout, L"TEST handle *fd: %i\n", *((int*) fd));
-} else {
-fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
-}
-*/
+// if (fd != *NULL_POINTER_STATE_CYBOI_MODEL) {
+// fwprintf(stdout, L"TEST handle *fd: %i\n", *((int*) fd));
+// } else {
+// fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
+// }
 
     // The comparison result.
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
@@ -139,10 +136,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
 //?? fwprintf(stdout, L"TEST handle part: %i\n", r);
 
             // Handle compound part signal.
-            //
-            // CAUTION! The signal part properties are possibly
-            // necessary one day for pre- and post conditions etc.
-            handle_part(md, mc, pd, pc, p1, p2, p3, p4, p5);
+            handle_part(md, mc, pd, pc, p1, p2, p3, p4, p5, p6);
         }
     }
 
@@ -189,7 +183,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
             deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc, p2);
 
             // Handle signal.
-            handle(part, p1, p2, p3, p4, p5);
+            handle(part, p1, p2, p3, p4, p5, p6);
         }
     }
 
@@ -216,7 +210,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
             deserialise_knowledge((void*) &part, p2, (void*) &pathd, (void*) &pathc, p2);
 
             // Handle signal.
-            handle(part, p1, p2, p3, p4, p5);
+            handle(part, p1, p2, p3, p4, p5, p6);
         }
     }
 
@@ -229,7 +223,7 @@ fwprintf(stdout, L"TEST handle NULL fd: %i\n", fd);
         if (fd != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
             // Handle primitive operation signal.
-            handle_operation(pd, pc, p1, p2, p3, p5, fd);
+            handle_operation(pd, pc, p1, p2, p3, p4, p6, fd);
         }
     }
 }
