@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -60,13 +60,15 @@
  * - shutdown
  *
  * in the following order:
- * - startup internal memory (global system parametres, e.g. for input/output)
- * - startup knowledge memory (statics = state knowledge + logic knowledge)
- * - startup signal memory (knowledge models to be executed as operations)
+ * - startup internal memory (system parametres; globally accessible; e.g. for input/output)
+ * - startup knowledge memory (heap; statics = state knowledge + logic knowledge)
+ * - startup stack memory (stack)
+ * - startup signal memory (event queue; knowledge models to be executed as operations)
  * - allocate startup signal and add to signal memory
  * - run signal checker loop (dynamics)
  * - deallocate startup signal
  * - shutdown signal memory
+ * - shutdown stack memory
  * - shutdown knowledge memory
  * - shutdown internal memory
  *
@@ -85,6 +87,8 @@ void manage(void* p0) {
     void* i = *NULL_POINTER_STATE_CYBOI_MODEL;
     // The knowledge memory part.
     void* k = *NULL_POINTER_STATE_CYBOI_MODEL;
+    // The stack memory item.
+    void* st = *NULL_POINTER_STATE_CYBOI_MODEL;
     // The signal memory item.
     void* s = *NULL_POINTER_STATE_CYBOI_MODEL;
 
@@ -215,6 +219,7 @@ void manage(void* p0) {
     // Variable allocation.
     //
 
+    //
     // Allocate internal memory data.
     //
     // CAUTION! Due to memory allocation handling, the size MUST NOT
@@ -222,12 +227,28 @@ void manage(void* p0) {
     //
     // CAUTION! The internal memory has a pre-defined count/size,
     // given by the constant INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT.
+    //
     allocate_array((void*) &i, (void*) INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT, (void*) POINTER_STATE_CYBOI_TYPE);
+    //
     // Allocate knowledge memory part.
     //
     // CAUTION! Due to memory allocation handling, the size MUST NOT
     // be negative or zero, but have at least a value of ONE.
+    //
     allocate_part((void*) &k, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
+    //
+    // Allocate stack memory item.
+    //
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
+    //
+    // CAUTION! It is given an initial size of 1024, in order
+    // to avoid steady reallocation, for better performance.
+    //
+    // CAUTION! The stack memory should be a simple array (item) only.
+    //
+    allocate_item((void*) &st, (void*) NUMBER_1024_INTEGER_STATE_CYBOI_MODEL, (void*) POINTER_STATE_CYBOI_TYPE);
+    //
     // Allocate signal memory item.
     //
     // CAUTION! Due to memory allocation handling, the size MUST NOT
@@ -236,11 +257,12 @@ void manage(void* p0) {
     // CAUTION! It is given an initial size of 1024, in order
     // to avoid steady reallocation, for better performance.
     //
-    // CAUTION! The signal memory should be a simple array only.
+    // CAUTION! The signal memory should be a simple array (item) only.
     // If it was a part, rubbish (garbage) collection would become effective
     // and manipulate the references count of child parts when removing them,
     // so that these might get deallocated while still needed.
     // But only the knowledge memory part has the right to do that.
+    //
     allocate_item((void*) &s, (void*) NUMBER_1024_INTEGER_STATE_CYBOI_MODEL, (void*) POINTER_STATE_CYBOI_TYPE);
 
     //
@@ -324,8 +346,7 @@ void manage(void* p0) {
     // CAUTION! ONLY ONE parametre can be handed over to threads!
     // Therefore, the knowledge memory and signal memory NEED TO BE ADDED
     // to the internal memory, in order to be forwardable to threads.
-    startup_internal_memory(i, (void*) &k, (void*) &s, (void*) &signal_memory_sleep_time,
-        (void*) NULL_POINTER_STATE_CYBOI_MODEL, (void*) NULL_POINTER_STATE_CYBOI_MODEL, (void*) NULL_POINTER_STATE_CYBOI_MODEL, (void*) NULL_POINTER_STATE_CYBOI_MODEL,
+    startup_internal_memory(i, (void*) &k, (void*) &st, (void*) &s, (void*) &signal_memory_sleep_time,
         (void*) &display_enable, (void*) &display_irq, (void*) &display_mutex, (void*) &display_sleep_time,
         (void*) &serial_enable, (void*) &serial_irq, (void*) &serial_mutex, (void*) &serial_sleep_time,
         (void*) &terminal_enable, (void*) &terminal_irq, (void*) &terminal_mutex, (void*) &terminal_sleep_time,
@@ -371,6 +392,8 @@ void manage(void* p0) {
 
     // Deallocate signal memory item.
     deallocate_item((void*) &s, (void*) POINTER_STATE_CYBOI_TYPE);
+    // Deallocate stack memory item.
+    deallocate_item((void*) &st, (void*) POINTER_STATE_CYBOI_TYPE);
     // Deallocate knowledge memory part.
     // CAUTION! This is the knowledge memory tree root node.
     // It has to be deallocated MANUALLY here.
