@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,19 +19,18 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef TESTER_SOURCE
 #define TESTER_SOURCE
 
-#include "../executor/container/basic/integer/left_integer_container.c"
-#include "../tester/applicator/applicator_tester.c"
-#include "../tester/controller/controller_tester.c"
-#include "../tester/executor/executor_tester.c"
-#include "../tester/unknown/unknown_tester.c"
-#include "../tester/logger_tester.c"
+#include "../constant/model/cyboi/state/boolean_state_cyboi_model.c"
+#include "../constant/model/cyboi/test/test_cyboi_model.c"
+#include "../executor/comparator/basic/integer/equal_integer_comparator.c"
+#include "../tester/copier_tester.c"
+#include "../tester/pointer_tester.c"
 
 //
 // Examples for source code testing via log messages.
@@ -65,49 +64,41 @@ void test(void* p0) {
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        compare_integer_equal((void*) &r, p0, (void*) ALL_UNIT_TEST_CYBOI_MODEL);
+        compare_integer_equal((void*) &r, p0, (void*) ALL_TEST_CYBOI_MODEL);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
             // CAUTION! There is NO specific test function for this case.
             // Instead, ALL OTHER test functions are to be called here.
 
-            test_controller(p0);
-            test_applicator(p0);
-            test_executor(p0);
-            test_unknown();
+            test_copier(p0);
+            test_pointer(p0);
+
+            // Call further test units here.
         }
     }
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        contain_integer_left((void*) &r, p0, (void*) APPLICATOR_UNIT_TEST_CYBOI_MODEL, (void*) CONTROLLER_UNIT_TEST_CYBOI_MODEL);
+        compare_integer_equal((void*) &r, p0, (void*) COPIER_TEST_CYBOI_MODEL);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            test_applicator(p0);
+            test_copier(p0);
         }
     }
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        contain_integer_left((void*) &r, p0, (void*) CONTROLLER_UNIT_TEST_CYBOI_MODEL, (void*) EXECUTOR_UNIT_TEST_CYBOI_MODEL);
+        compare_integer_equal((void*) &r, p0, (void*) POINTER_TEST_CYBOI_MODEL);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            test_controller(p0);
+            test_pointer(p0);
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        contain_integer_left((void*) &r, p0, (void*) EXECUTOR_UNIT_TEST_CYBOI_MODEL, (void*) NUMBER_1000_INTEGER_STATE_CYBOI_MODEL_ARRAY);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            test_executor(p0);
-        }
-    }
+    // Add further test units here.
 }
 
 /* TESTER_SOURCE */
