@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -72,18 +72,22 @@
  * @param p4 the source properties data (e.g. the signal memory index)
  * @param p5 the source properties count
  * @param p6 the knowledge memory part
- * @param p7 the internal memory data
- * @param p8 the minimum number of bytes to be received in one call of the read function
- * @param p9 the maximum number of bytes to be received in one call of the read function
- * @param p10 the format
- * @param p11 the language
- * @param p12 the encoding
- * @param p13 the channel
+ * @param p7 the stack memory item
+ * @param p8 the internal memory data
+ * @param p9 the blocking flag
+ * @param p10 the minimum number of bytes to be received in one call of the read function
+ * @param p11 the maximum number of bytes to be received in one call of the read function
+ * @param p12 the format
+ * @param p13 the language
+ * @param p14 the encoding
+ * @param p15 the channel
  */
-void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13) {
+void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15) {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Receive data.");
 
+//?? fwprintf(stdout, L"TEST receive data p15: %i\n", *((int*) p15));
+
     // The pointer message item, e.g. an xcb display event or win32 input record.
     void* p = *NULL_POINTER_STATE_CYBOI_MODEL;
     // The integer message item, e.g. a datetime or random number.
@@ -137,19 +141,19 @@ void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, vo
     b = c;
 
     // Select buffer.
-    receive_select((void*) &b, (void*) &p0, (void*) &p, (void*) &i, (void*) &s, p13);
+    receive_select((void*) &b, (void*) &p0, (void*) &p, (void*) &i, (void*) &s, p15);
     // Read message.
-    receive_read((void*) &ad, (void*) &ac, b, p2, p3, p4, p5, p6, p7, p8, p9, p13);
-    if ((p11 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p11) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
+    receive_read((void*) &ad, (void*) &ac, b, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p15);
+    if ((p13 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p13) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
 //?? fwprintf(stdout, L"TEST receive data read *ac: %i\n", *((int*) ac));
 //?? fwprintf(stdout, L"TEST receive data read ad: %s\n", (char*) ad);
-//?? fwprintf(stdout, L"TEST receive data read *p12: %i\n", *((int*) p12));
+//?? fwprintf(stdout, L"TEST receive data read *p14: %i\n", *((int*) p14));
     }
     // Extract message.
 //??    receive_extract((void*) &ad, (void*) &ac, e, ad, ac, p??);
     // Decode message.
-    receive_decode((void*) &ad, (void*) &ac, s, ad, ac, p12);
-    if ((p11 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p11) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
+    receive_decode((void*) &ad, (void*) &ac, s, ad, ac, p14);
+    if ((p13 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p13) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
 //?? fwprintf(stdout, L"TEST receive data decode *ac: %i\n", *((int*) ac));
 //?? fwprintf(stdout, L"TEST receive data decode ad: %s\n", (char*) ad);
     }
@@ -157,13 +161,13 @@ void receive_data(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, vo
     // CAUTION! The buffer argument may be of e.g.
     // type "char" or type "wchar_t" or type "void*", which is IRRELEVANT.
     // This function knows how to handle it, depending on the given language.
-    receive_deserialise(p0, p1, ad, ac, p6, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, p10, p11);
-    if ((p11 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p11) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
+    receive_deserialise(p0, p1, ad, ac, p6, p7, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, *NULL_POINTER_STATE_CYBOI_MODEL, p12, p13);
+    if ((p13 != *NULL_POINTER_STATE_CYBOI_MODEL) && (*((int*) p13) == *BINARY_MESSAGE_STATE_CYBOI_LANGUAGE)) {
 //?? fwprintf(stdout, L"TEST receive data deserialise *ac: %i\n", *((int*) ac));
 //?? fwprintf(stdout, L"TEST receive data deserialise ad: %s\n", (char*) ad);
     }
     // Deallocate display event.
-    receive_deallocate(b, p13);
+    receive_deallocate(b, p15);
 
     // Deallocate pointer message item.
     deallocate_item((void*) &p, (void*) POINTER_STATE_CYBOI_TYPE);
