@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,25 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef ARRAY_SUBSEQUENCE_COMPARATOR_SOURCE
 #define ARRAY_SUBSEQUENCE_COMPARATOR_SOURCE
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
+#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
 #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/modifier/copier/integer_copier.c"
-#include "../../../executor/memoriser/offset_adder.c"
-#include "../../../executor/modifier/copier/value_copier.c"
-#include "../../../executor/memoriser/size_determiner.c"
+#include "../../../executor/calculator/basic/integer/add_integer_calculator.c"
+#include "../../../executor/calculator/basic/integer/subtract_integer_calculator.c"
+#include "../../../executor/comparator/basic/integer/equal_integer_comparator.c"
+#include "../../../executor/comparator/basic/integer/greater_or_equal_integer_comparator.c"
+#include "../../../executor/comparator/basic/array_comparator.c"
 #include "../../../logger/logger.c"
 
 /**
@@ -58,7 +55,7 @@ void compare_subsequence_array_elements(void* p0, void* p1, void* p2, void* p3,
     // The loop count.
     int c = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
     // The comparison result.
-    int r = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
+    int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
     // The loop variable.
     int j = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
 
@@ -123,7 +120,7 @@ void compare_subsequence_array(void* p0, void* p1, void* p2, void* p3, void* p4,
     // The comparison result.
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
-    compare_integer((void*) &r, p5, p6, (void*) GREATER_OR_EQUAL_COMPARE_LOGIC_CYBOI_FORMAT);
+    compare_integer_greater_or_equal((void*) &r, p5, p6);
 
     if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
