@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,19 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef PART_ALLOCATOR_SOURCE
 #define PART_ALLOCATOR_SOURCE
 
+#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../constant/name/cyboi/state/part_state_cyboi_name.c"
+#include "../../../executor/memoriser/allocator/array_allocator.c"
 #include "../../../executor/memoriser/allocator/item_allocator.c"
 #include "../../../logger/logger.c"
 #include "../../../variable/reference_counter.c"
 
+//
+// Forward declaration.
+//
+
+void copy_array_forward(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5);
+void overwrite_item_element(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7);
+
 /**
  * Allocates the part.
  *
@@ -55,6 +64,14 @@ void allocate_part(void* p0, void* p1, void* p2) {
         // If not deserialised at startup, they have to be translated
         // from characters into an integer value each time the operation is called.
         //
+        // A test commenting out channel, encoding, language, format
+        // showed that cybol applications did not work anymore.
+        // Therefore, they are added for now but possibly removed in the future,
+        // if it is verified that they are not needed at runtime anymore.
+        // However, they seem to be NECESSARY, since the XML parser
+        // creates parts that contain that data which are needed
+        // and processed afterwards in the CYBOL parser.
+        //
 
         // The references, name, channel, encoding, language, format, type, model, properties.
         // CAUTION! The "format" contains the mime type value, e.g. "text/cybol";
