@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -162,7 +162,7 @@ fwprintf(stdout, L"TEST deserialise path nmd: %ls\n", (wchar_t*) nmd);
             // In order to avoid this, the p0 result parametre
             // gets only assigned the final part in the
             // block with break condition further above.
-            get_name_part_element((void*) &p, p1, nmd, nmc, p4);
+            get_name_part_element((void*) &p, p1, nmd, nmc, p4, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
 
 /*??
 fwprintf(stdout, L"TEST deserialise path p: %i\n", p);
