@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -45,10 +45,11 @@
  * @param p4 the position x
  * @param p5 the position y
  * @param p6 the knowledge memory part
- * @param p7 the layout data
- * @param p8 the layout count
+ * @param p7 the stack memory item
+ * @param p8 the layout data
+ * @param p9 the layout count
  */
-void serialise_layout_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8) {
+void serialise_layout_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Serialise layout part.");
 
@@ -79,7 +80,7 @@ void serialise_layout_part(void* p0, void* p1, void* p2, void* p3, void* p4, voi
         }
 
         // Serialise layout part element.
-        serialise_layout_part_element(p0, (void*) &j, p2, p3, p4, p5, p6, p7, p8);
+        serialise_layout_part_element(p0, (void*) &j, p2, p3, p4, p5, p6, p7, p8, p9);
 
         // Increment loop variable.
         j++;
