@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,14 +30,12 @@
 #include "../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
 #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../../constant/type/cyboi/state_cyboi_type.c"
 #include "../../../executor/calculator/basic/integer/add_integer_calculator.c"
-#include "../../../executor/calculator/basic/integer/multiply_integer_calculator.c"
+#include "../../../executor/calculator/basic/integer/subtract_integer_calculator.c"
+#include "../../../executor/comparator/basic/integer/array_comparator.c"
+#include "../../../executor/comparator/basic/integer/greater_or_equal_integer_comparator.c"
 #include "../../../executor/modifier/copier/integer_copier.c"
-#include "../../../executor/memoriser/offset_adder.c"
-#include "../../../executor/modifier/copier/value_copier.c"
-#include "../../../executor/memoriser/size_determiner.c"
 #include "../../../logger/logger.c"
 
 /**
