@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2015. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.17.0 2015-04-20
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,19 +29,14 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "../../../constant/type/cyboi/state_cyboi_type.c"
+#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../../constant/model/cyboi/log/message_log_cyboi_model.c"
-#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../../../executor/calculator/basic/integer/add_integer_calculator.c"
-#include "../../../executor/calculator/basic/integer/multiply_integer_calculator.c"
-#include "../../../executor/memoriser/reallocator/item_reallocator.c"
-#include "../../../executor/memoriser/size_determiner.c"
-#include "../../../executor/modifier/overwriter/array_overwriter.c"
+#include "../../../constant/type/cyboi/state_cyboi_type.c"
 #include "../../../logger/logger.c"
 
 /**
- * Finds a part with the searched name array in the investigated item.
+ * Finds a part with the searched name in the investigated item.
  *
  * @param p0 the index (if found; unchanged otherwise)
  * @param p1 the investigated item (each element pointing to a part)
@@ -65,7 +60,7 @@ void find_name_item_element(void* p0, void* p1, void* p2, void* p3) {
 }
 
 /**
- * Finds a part with the searched name item in the investigated item.
+ * Finds a part with the searched name in the investigated item.
  *
  * @param p0 the index (if found; unchanged otherwise)
  * @param p1 the investigated item (each element pointing to a part)
