@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,17 +19,20 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef COMMUNICATOR_TESTER
 #define COMMUNICATOR_TESTER
 
-#ifdef WIN32
+#ifdef __APPLE__
+    #include <termios.h>
+#elif WIN32
     #include <windows.h>
-#endif
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#elif GNU_LINUX_OPERATING_SYSTEM
+    #include <termios.h>
+#else
     #include <termios.h>
 #endif
 
@@ -43,19 +46,21 @@
 //?? and freeglut.h would not be needed.
 //?? #include <GL/freeglut.h>
 #include <sys/types.h>
-#include <dirent.h>
 #include <errno.h>
 #include <locale.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifndef _MSC_VER
+#include <dirent.h>
 #include <unistd.h>
+#endif
 #include <wchar.h>
 
-#include "../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../logger/logger.c"
+#include "../../../constant/model/cyboi/state/boolean_state_cyboi_model.c"
+#include "../../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
+#include "../../../constant/type/cyboi/state_cyboi_type.c"
+#include "../../../logger/logger.c"
 
 /**
  * Tests the standard output and error stream.
@@ -108,11 +113,19 @@ void test_wide_character_wprintf() {
 //    static wchar_t* TEST_WIDE_CHARACTER_STRING_WITH_TERMINATION = TEST_WIDE_CHARACTER_STRING_WITH_TERMINATION_ARRAY;
 
 //??    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_ARRAY[] = {L'r', L'e', L'c', L't', L'a', L'n', L'為', L'l', L'e'};
-    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_ARRAY[] = {L'r', L'e', L'c', L't', L'a', L'n', L'─', L'l', L'e'};
+
+    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_ARRAY[] = { L'r', L'e', L'c', L't', L'a', L'n', 0x2500, L'l', L'e'};
+    // Compiler warning in VS: L'─' doesn't work correctly
+    //static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_ARRAY[] = { L'r', L'e', L'c', L't', L'a', L'n', L'─', L'l', L'e' };
+
     static wchar_t* TEST_WIDE_CHARACTER_STRING_WITH_L = TEST_WIDE_CHARACTER_STRING_WITH_L_ARRAY;
 
 //??    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION_ARRAY[] = {L'r', L'e', L'c', L't', L'a', L'n', L'為', L'l', L'e', 0x0000};
-    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION_ARRAY[] = {L'r', L'e', L'c', L't', L'a', L'n', L'─', L'l', L'e', 0x0000};
+
+    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION_ARRAY[] = { L'r', L'e', L'c', L't', L'a', L'n', 0x2500, L'l', L'e', 0x0000 };
+    // Compiler warning in VS: L'─' doesn't work correctly
+    //static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION_ARRAY[] = { L'r', L'e', L'c', L't', L'a', L'n', L'─', L'l', L'e', 0x0000 };
+
     static wchar_t* TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION = TEST_WIDE_CHARACTER_STRING_WITH_L_AND_TERMINATION_ARRAY;
 
 //??    static wchar_t TEST_WIDE_CHARACTER_STRING_WITH_UTF_8_CODES_AND_TERMINATION_ARRAY[] = {0x0072, 0x0065, 0x0063, 0x0074, 0x0061, 0x006E, 0xE7, 0x82, 0xBA, 0x006C, 0x0065, 0x0000};
@@ -168,7 +181,9 @@ void test_wide_character_output() {
 
     log_write((void*) stdout, L"Test wide character array with termination:\n");
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef WIN32
+        //?? Add Linux support
+#else
     // Possible locales are: LANG, LC_CTYPE, LC_ALL.
     // CAUTION! This setting is necessary for UTF-8 Unicode characters to work.
     char* loc = setlocale(LC_ALL, "");
@@ -184,8 +199,8 @@ void test_wide_character_output() {
     // CAUTION! Due to memory allocation handling, the size MUST NOT
     // be negative or zero, but have at least a value of ONE.
 //??        allocate((void*) &t, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) INTEGER_NUMBER_STATE_PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
-    to = (struct termios*) malloc(sizeof(struct termios));
-    tw = (struct termios*) malloc(sizeof(struct termios));
+    to = (struct termios*) malloc(sizeof (struct termios));
+    tw = (struct termios*) malloc(sizeof (struct termios));
 
     // Initialise terminal internals.
     // Set file stream.
@@ -260,7 +275,10 @@ void test_wide_character_output() {
 //??    log_write((void*) stdout, (wchar_t*) ts, t);
 
     // Destroy terminated control sequences.
-    deallocate_array((void*) &ts, (void*) &tsc, (void*) &tss, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &ts, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &tss, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
     // UTF-8 still allows you to use C1 control characters such as CSI, even
     // though UTF-8 also uses bytes in the range 0x80-0x9F. It is important to
@@ -352,7 +370,10 @@ void test_communicator_file_read() {
         j++;
     }
 
-    deallocate_array((void*) &a, (void*) &ac, (void*) &as, (void*) &CHARACTER_ARRAY);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &a, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &as, (void*) &CHARACTER_ARRAY);
 */
 }
 
@@ -388,7 +409,9 @@ void test_communicator_console_input() {
 
     log_write((void*) stdout, L"Test communicator console input:\n");
 
-#ifdef GNU_LINUX_OPERATING_SYSTEM
+#ifdef WIN32
+    //?? Add Win32 support
+#else
     // The terminal device name.
     FILE* t = (FILE*) *NULL_POINTER_STATE_CYBOI_MODEL;
     // The old termios settings.
@@ -397,8 +420,8 @@ void test_communicator_console_input() {
     struct termios* tn = (struct termios*) *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Allocate terminal internals.
-    to = (struct termios*) malloc(sizeof(struct termios));
-    tn = (struct termios*) malloc(sizeof(struct termios));
+    to = (struct termios*) malloc(sizeof (struct termios));
+    tn = (struct termios*) malloc(sizeof (struct termios));
 
     // Set file stream.
     t = stdin;
@@ -635,20 +658,22 @@ void test_communicator_mesa_opengl() {
  */
 void test_communicator() {
 
-//    fwprintf(stdout, L"TEST communicator.\n");
+    fwprintf(stdout, L"TEST communicator.\n");
 
-//    test_stdout_stdout();
-//    test_wide_character_wprintf();
-//    test_wide_character_output();
+/*??
+    test_stdout_stdout();
+    test_wide_character_wprintf();
+    test_wide_character_output();
 
-//    test_communicator_file_read();
-//    test_communicator_file_write();
+    test_communicator_file_read();
+    test_communicator_file_write();
 
-//    test_communicator_console_input();
-//    test_communicator_console_output();
+    test_communicator_console_input();
+    test_communicator_console_output();
 
-//    test_communicator_mesa_opengl_standard(int argc, char **argv);
-//    test_communicator_mesa_opengl(*NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (char**) NULL_POINTER_STATE_CYBOI_MODEL);
+    test_communicator_mesa_opengl_standard(int argc, char **argv);
+    test_communicator_mesa_opengl(*NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (char**) NULL_POINTER_STATE_CYBOI_MODEL);
+*/
 }
 
 /* COMMUNICATOR_TESTER */
