@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,34 +19,24 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef COMPARATOR_TESTER
 #define COMPARATOR_TESTER
 
-#include "../constant/format/cyboi/logic_cyboi_format.c"
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../executor/comparator/all/array_all_comparator.c"
-#include "../executor/comparator/all/part_all_comparator.c"
-#include "../executor/comparator/prefix/array_prefix_comparator.c"
-#include "../executor/comparator/subsequence/array_subsequence_comparator.c"
-#include "../executor/comparator/suffix/array_suffix_comparator.c"
-#include "../executor/modifier/inserter/part_inserter.c"
-#include "../executor/modifier/overwriter/part_overwriter.c"
-#include "../logger/logger.c"
-
 /**
  * Tests the ascii character - wide character equality.
  */
 void test_comparator_ascii_character() {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test comparator ascii character.");
+    fwprintf(stdout, L"TEST comparator ascii character.\n");
 
     char test = 'a';
 
-    if (test = *LATIN_SMALL_LETTER_A_UNICODE_CHARACTER_CODE_MODEL) {
+    if (test == *LATIN_SMALL_LETTER_A_UNICODE_CHARACTER_CODE_MODEL) {
 
         log_write((void*) stdout, L"Characters ARE equal.\n");
 
@@ -62,6 +52,7 @@ void test_comparator_ascii_character() {
 void test_comparator_array() {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test comparator array.");
+    fwprintf(stdout, L"TEST comparator array.\n");
 
     // The comparison result.
     int r = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
@@ -131,6 +122,7 @@ void test_comparator_array() {
 void test_comparator_part() {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test comparator part.");
+    fwprintf(stdout, L"TEST comparator part.\n");
 
     // Declare parts.
     void* w1 = *NULL_POINTER_STATE_CYBOI_MODEL;
@@ -284,6 +276,7 @@ void test_comparator_part() {
 void test_comparator_pointer() {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test comparator pointer.");
+    fwprintf(stdout, L"TEST comparator pointer.\n");
 
     int i = 1;
     int n = 2;
@@ -325,6 +318,7 @@ void test_comparator_pointer() {
 void test_comparator_double() {
 
     log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test comparator double.");
+    fwprintf(stdout, L"TEST comparator double.\n");
 
     double l = 1.2;
     double r = 1.3;
@@ -368,13 +362,13 @@ void test_comparator_double() {
  */
 void test_comparator() {
 
-//    fwprintf(stdout, L"TEST comparator.\n");
-
-//    test_comparator_ascii_character();
-//    test_comparator_array();
-//    test_comparator_part();
-//    test_comparator_pointer();
-//    test_comparator_double();
+    fwprintf(stdout, L"TEST executor/comparator.\n");
+    test_comparator_ascii_character();
+    test_comparator_array();
+    //test_comparator_part(); //@TODO: segmentation fault!
+    fwprintf(stdout, L"TEST segmentation fault for test_comparator_part.\n");
+    test_comparator_pointer();
+    test_comparator_double();
 }
 
 /* COMPARATOR_TESTER */
