@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,23 +19,22 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef FINDER_TESTER
 #define FINDER_TESTER
 
-#include "../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
-#include "../executor/communicator/sender/file/stream_file_sender.c"
-#include "../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../executor/accessor/name_getter/part_name_getter.c"
-#include "../executor/representer/deserialiser/knowledge/knowledge_deserialiser.c"
-#include "../executor/searcher/finder/array_finder.c"
-#include "../executor/searcher/finder/item_finder.c"
-#include "../executor/searcher/finder/part_finder.c"
-#include "../logger/logger.c"
-#include "../tester/part_as_model_diagram_tester.c"
+#include "../../../../constant/model/cyboi/state/negative_integer_state_cyboi_model.c"
+#include "../../../../executor/converter/encoder/utf/utf_8_encoder.c"
+#include "../../../../executor/accessor/name_getter/part_name_getter.c"
+#include "../../../../executor/representer/deserialiser/knowledge/knowledge_deserialiser.c"
+#include "../../../../executor/searcher/finder/array_finder.c"
+#include "../../../../executor/searcher/finder/item_finder.c"
+#include "../../../../executor/searcher/finder/part_finder.c"
+#include "../../../../logger/logger.c"
+#include "../../../../tester/part_as_model_diagram_tester.c"
 
 /**
  * Tests the part by hierarchical name finder.
@@ -192,17 +191,17 @@ void test_finder_part_hierarchical() {
     //
 
     // Get part on first hierarchy level.
-    deserialise_knowledge((void*) &p1, application, (void*) &n1, (void*) &n1c);
+    deserialise_knowledge((void*) &p1, application, (void*) &n1, (void*) &n1c, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Get part on second hierarchy level.
-    deserialise_knowledge((void*) &p2, application, (void*) &n2, (void*) &n2c);
+    deserialise_knowledge((void*) &p2, application, (void*) &n2, (void*) &n2c, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Get meta property of part on second hierarchy level.
-    deserialise_knowledge((void*) &p3, application, (void*) &n3, (void*) &n3c);
+    deserialise_knowledge((void*) &p3, application, (void*) &n3, (void*) &n3c, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Get part of a part directly.
-    deserialise_knowledge((void*) &p4, p1, (void*) &n4, (void*) &n4c);
+    deserialise_knowledge((void*) &p4, p1, (void*) &n4, (void*) &n4c, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Get meta property of another part on a lower hierarchy level.
-    deserialise_knowledge((void*) &p5, p1, (void*) &n5, (void*) &n5c);
+    deserialise_knowledge((void*) &p5, p1, (void*) &n5, (void*) &n5c, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Get meta property of a part directly.
-    deserialise_knowledge((void*) &p6, p4, (void*) &n6, (void*) &n6c);
+    deserialise_knowledge((void*) &p6, p4, (void*) &n6, (void*) &n6c, *NULL_POINTER_STATE_CYBOI_MODEL);
 
     //
     // Output determined result parts.
@@ -328,7 +327,7 @@ void test_finder_part_by_name() {
     void* f = *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Find part in whole by name.
-    get_name_part_element((void*) &f, w, (void*) L"part_two", (void*) NUMBER_8_INTEGER_STATE_CYBOI_MODEL, (void*) MODEL_PART_STATE_CYBOI_NAME);
+    get_name_part_element((void*) &f, w, (void*) L"part_two", (void*) NUMBER_8_INTEGER_STATE_CYBOI_MODEL, (void*) MODEL_PART_STATE_CYBOI_NAME, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
 
     //
     // Output test results.
@@ -419,11 +418,11 @@ void test_finder_array() {
  */
 void test_finder() {
 
-//    fwprintf(stdout, L"TEST finder.\n");
-
-//    test_finder_part_hierarchical();
-//    test_finder_part_by_name();
-//    test_finder_array();
+    //@todo:Find segmentation fault.
+    fwprintf(stdout, L"TODO: Find segmentation fault.");
+    //test_finder_part_hierarchical();
+    //test_finder_part_by_name();
+    //test_finder_array();
 }
 
 /* FINDER_TESTER */
