@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,29 +19,13 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef MODIFIER_TESTER
 #define MODIFIER_TESTER
-
-#include <wchar.h>
-
-#include "../constant/format/cyboi/state_cyboi_format.c"
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../executor/communicator/sender/file/stream_file_sender.c"
-#include "../executor/converter/encoder/utf/utf_8_encoder.c"
-#include "../executor/modifier/copier/array_copier.c"
-#include "../executor/modifier/copier/part_copier.c"
-#include "../executor/memoriser/allocator/part_allocator.c"
-#include "../executor/memoriser/deallocator/part_deallocator.c"
-#include "../executor/modifier/inserter/array_inserter.c"
-#include "../executor/modifier/overwriter/part_overwriter.c"
-#include "../executor/modifier/remover/array_remover.c"
-#include "../logger/logger.c"
-#include "../tester/part_as_model_diagram_tester.c"
-
+#include "copier/copier_tester.c"
 /**
  * Tests part modification on compound part.
  */
@@ -312,7 +296,10 @@ void test_modifier_array() {
     fwprintf(stdout, L"TEST c: %i\n", c);
     fwprintf(stdout, L"TEST s: %i\n", s);
 
-    deallocate_array((void*) &w, (void*) &c, (void*) &s, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &w, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &s, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -323,11 +310,13 @@ void test_modifier_array() {
  */
 void test_modifier() {
 
-//    fwprintf(stdout, L"TEST modifier.\n");
-
-//    test_modifier_part_compound();
-//    test_modifier_part_wide_character_insert();
-//    test_modifier_array();
+    fwprintf(stdout, L"TEST executor/modifier.\n");
+    test_modifier_part_compound();
+    test_modifier_part_wide_character_insert();
+    test_modifier_array();
+    fwprintf(stdout, L"TEST executor/modifier/copier.\n");
+    test_copier();
+    //
 }
 
 /* MODIFIER_TESTER */
