@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,19 +19,13 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef POINTER_TESTER
 #define POINTER_TESTER
 
-#include <stdio.h>
-#include <wchar.h>
-
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../constant/model/cyboi/state/boolean_state_cyboi_model.c"
-#include "../logger/logger.c"
 
 /**
  * Tests the pointer null value as subroutine.
@@ -122,7 +116,10 @@ void test_pointer_return() {
     fwprintf(stdout, L"r: %ls\n", (wchar_t*) r);
 
     // Destroy character array.
-    deallocate_array((void*) &cs, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &cs, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -179,14 +176,17 @@ void test_character_array_single_element() {
             break;
         }
 
-        catest = (wchar_t*) (c + i);
+        catest = (wchar_t*) ((size_t) c + i);
         fwprintf(stdout, L"ca: %c\n", *catest);
 
         i++;
     }
 
     // Destroy character array.
-    deallocate_array((void*) &c, (void*) &cs, (void*) &cs, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &c, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &cs, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -250,7 +250,10 @@ void test_character_array_multiple_elements() {
     log_write((void*) stdout, (wchar_t*) r);
 
     // Destroy destination array.
-    deallocate_array((void*) &d, (void*) &ns, (void*) &ns, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &d, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &ns, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -317,9 +320,12 @@ void test_integer_array() {
     fwprintf(stdout, L"post result2: %i\n", *result2);
 
     // Deallocate test knowledge model.
-    deallocate_array((void*) &m, (void*) mc, (void*) ms, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
-    deallocate_array((void*) &mc, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
-    deallocate_array((void*) &ms, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &m, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) ms, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &mc, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &ms, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -379,7 +385,10 @@ void test_pointer_array() {
     //
 
     // Destroy pointer array.
-    deallocate_array((void*) &p, (void*) &ps, (void*) &ps, (void*) POINTER_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &p, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &ps, (void*) POINTER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -429,7 +438,10 @@ void test_pointer_array_with_null_values() {
     fwprintf(stdout, L"NULL_POINTER_STATE_CYBOI_MODEL: %i \n", NULL_POINTER_STATE_CYBOI_MODEL);
     fwprintf(stdout, L"*NULL_POINTER_STATE_CYBOI_MODEL: %i \n", *NULL_POINTER_STATE_CYBOI_MODEL);
 
-    deallocate_array((void*) &a, (void*) &as, (void*) &as, (void*) POINTER_STATE_CYBOI_TYPE);
+    // CAUTION! The second argument "count" is NULL,
+    // since it is only needed for looping elements of type PART,
+    // in order to decrement the rubbish (garbage) collection counter.
+    deallocate_array((void*) &a, *NULL_POINTER_STATE_CYBOI_MODEL, (void*) &as, (void*) POINTER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -447,7 +459,7 @@ void test_pointer_array_with_null_values() {
  * overwrite_array(m, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_10_INTEGER_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
  * int* c = m + 2;
  * should be: = 10 + 2 = 12
- * but it is: = 10 + (2 * sizeof(int)) = 10 + 8 = 18
+ * but it is: = 10 + (2 * sizeof (int)) = 10 + 8 = 18
  */
 void test_pointer_addition() {
 
@@ -464,6 +476,17 @@ void test_pointer_addition() {
     unsigned long* ul = (unsigned long*) malloc(*NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
 
     // Calculate void pointer addresses using various formulas and casts.
+#ifdef _MSC_VER
+    // No support for void pointer arithmetic in VS!
+    void* v0 = v; // unchanged
+    void* v1 = (void*) ((size_t) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v2 = (void*) ((size_t) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v3 = (void*) (((size_t) v) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v4 = (void*) ((size_t) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v5 = (void*) ((size_t) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v6 = (void*) (((size_t) v) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    void* v7 = (void*) ((size_t) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     void* v0 = v; // unchanged
     void* v1 = v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     void* v2 = (void*) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
@@ -472,6 +495,7 @@ void test_pointer_addition() {
     void* v5 = (void*) v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     void* v6 = ((void*) v) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     void* v7 = (void*) (v + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#endif
 
     fwprintf(stdout, L"void pointer v0: %i\n", v0);
     fwprintf(stdout, L"void pointer v1: %i\n", v1);
@@ -488,8 +512,14 @@ void test_pointer_addition() {
     int* i2 = (int*) i + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     int* i3 = ((int*) i) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     int* i4 = (int*) (i + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
+#ifdef _MSC_VER
+    // No support for void pointer arithmetic in VS!
+    int* i5 = (void*) ((size_t) i + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    int* i6 = (void*) (((size_t) i) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     int* i5 = (void*) i + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     int* i6 = ((void*) i) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
+#endif
     int* i7 = (void*) (i + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
 
     fwprintf(stdout, L"int pointer i0: %i\n", i0);
@@ -507,8 +537,14 @@ void test_pointer_addition() {
     double* d2 = (double*) d + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 8
     double* d3 = ((double*) d) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 8
     double* d4 = (double*) (d + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 8
+#ifdef _MSC_VER
+    // No support for void pointer arithmetic in VS!
+    double* d5 = (void*) ((size_t) d + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    double* d6 = (void*) (((size_t) d) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     double* d5 = (void*) d + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     double* d6 = ((void*) d) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
+#endif
     double* d7 = (void*) (d + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 8
 
     fwprintf(stdout, L"double pointer d0: %i\n", d0);
@@ -526,8 +562,13 @@ void test_pointer_addition() {
     char* c2 = (char*) c + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     char* c3 = ((char*) c) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     char* c4 = (char*) (c + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#ifdef _MSC_VER
+    char* c5 = (void*) ((size_t) c + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    char* c6 = (void*) (((size_t) c) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     char* c5 = (void*) c + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     char* c6 = ((void*) c) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
+#endif
     char* c7 = (void*) (c + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
 
     fwprintf(stdout, L"char pointer c0: %i\n", c0);
@@ -545,8 +586,13 @@ void test_pointer_addition() {
     wchar_t* wc2 = (wchar_t*) wc + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     wchar_t* wc3 = ((wchar_t*) wc) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     wchar_t* wc4 = (wchar_t*) (wc + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
+#ifdef _MSC_VER
+    wchar_t* wc5 = (void*) ((size_t) wc + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    wchar_t* wc6 = (void*) (((size_t) wc) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     wchar_t* wc5 = (void*) wc + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     wchar_t* wc6 = ((void*) wc) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
+#endif
     wchar_t* wc7 = (void*) (wc + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
 
     fwprintf(stdout, L"wchar_t pointer wc0: %i\n", wc0);
@@ -564,8 +610,13 @@ void test_pointer_addition() {
     unsigned long* ul2 = (unsigned long*) ul + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     unsigned long* ul3 = ((unsigned long*) ul) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 4
     unsigned long* ul4 = (unsigned long*) (ul + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
+#ifdef _MSC_VER
+    unsigned long* ul5 = (void*) ((size_t) ul + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+    unsigned long* ul6 = (void*) (((size_t) ul) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 1
+#else
     unsigned long* ul5 = (void*) ul + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
     unsigned long* ul6 = ((void*) ul) + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL; // increased by 1
+#endif
     unsigned long* ul7 = (void*) (ul + *NUMBER_1_INTEGER_STATE_CYBOI_MODEL); // increased by 4
 
     fwprintf(stdout, L"unsigned long pointer ul0: %i\n", ul0);
@@ -594,22 +645,22 @@ void test_pointer_addition() {
  */
 void test_pointer() {
 
-//    fwprintf(stdout, L"TEST pointer.\n");
+    fwprintf(stdout, L"Test pointer.\n");
 
-//    test_pointer_null();
-//    test_pointer_cast();
-//    test_pointer_return();
+    test_pointer_null();
+    test_pointer_cast();
+    test_pointer_return();
 
-//    test_character_array_with_termination();
-//    test_character_array_single_element();
-//    test_character_array_multiple_elements();
+    test_character_array_with_termination();
+    test_character_array_single_element();
+    test_character_array_multiple_elements();
 
-//    test_integer_array();
+    test_integer_array();
 
-//    test_pointer_array();
-//    test_pointer_array_with_null_values();
+    test_pointer_array();
+    test_pointer_array_with_null_values();
 
-//    test_pointer_addition();
+    test_pointer_addition();
 }
 
 /* POINTER_TESTER */
