@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2013. Christian Heller.
+ * Copyright (C) 1999-2016. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,14 +19,13 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.15.0 2013-09-22
+ * @version CYBOP 0.18.0 2016-12-21
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef SERIAL_PORT_TESTER
 #define SERIAL_PORT_TESTER
 
-#include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <fcntl.h>
@@ -34,25 +33,35 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <termios.h>
-#include <unistd.h>
 
-#include "../constant/type/cyboi/state_cyboi_type.c"
-#include "../executor/modifier/copier/array_copier.c"
-#include "../executor/modifier/copier/item_copier.c"
-#include "../executor/modifier/copier/part_copier.c"
-#include "../executor/memoriser/allocator/array_allocator.c"
-#include "../executor/memoriser/allocator/item_allocator.c"
-#include "../executor/memoriser/allocator/part_allocator.c"
-#include "../executor/memoriser/deallocator/array_deallocator.c"
-#include "../executor/memoriser/deallocator/item_deallocator.c"
-#include "../executor/memoriser/deallocator/part_deallocator.c"
-#include "../executor/modifier/overwriter/item_overwriter.c"
-#include "../executor/modifier/overwriter/part_overwriter.c"
-#include "../executor/runner/nano_sleeper.c"
-#include "../executor/runner/second_sleeper.c"
-#include "../executor/runner/sleeper.c"
-#include "../logger/logger.c"
+// TODO: Implement constants / functions for use in WINDOWS
+// Maybe this helps: http://cboard.cprogramming.com/c-programming/147281-rs232-programming-visual-cplusplus-2010-a.html
+#ifndef _MSC_VER
+#include <windows.h>
+#include <WinDef.h>
+#include <io.h>
+#else
+#include <unistd.h>
+#include <sys/ioctl.h>
+#include <termios.h>
+#endif
+
+#include "../../../constant/type/cyboi/state_cyboi_type.c"
+#include "../../../executor/modifier/copier/array_copier.c"
+#include "../../../executor/modifier/copier/item_copier.c"
+#include "../../../executor/modifier/copier/part_copier.c"
+#include "../../../executor/memoriser/allocator/array_allocator.c"
+#include "../../../executor/memoriser/allocator/item_allocator.c"
+#include "../../../executor/memoriser/allocator/part_allocator.c"
+#include "../../../executor/memoriser/deallocator/array_deallocator.c"
+#include "../../../executor/memoriser/deallocator/item_deallocator.c"
+#include "../../../executor/memoriser/deallocator/part_deallocator.c"
+#include "../../../executor/modifier/overwriter/item_overwriter.c"
+#include "../../../executor/modifier/overwriter/part_overwriter.c"
+#include "../../../executor/runner/nano_sleeper.c"
+#include "../../../executor/runner/second_sleeper.c"
+#include "../../../executor/runner/sleeper.c"
+#include "../../../logger/logger.c"
 
 int Cport[28], error;
 
@@ -145,7 +154,7 @@ int OpenComport(int comport_number, int baudrate) {
         return(1);
     }
 
-    memset(&new_port_settings, 0, sizeof(new_port_settings));  // clear the new struct
+    memset(&new_port_settings, 0, sizeof (new_port_settings));  // clear the new struct
 
 fwprintf(stdout, L"TEST baudrate: %i\n", baudr);
 
@@ -367,10 +376,10 @@ void test_serial_port_sleep() {
  */
 void test_serial_port() {
 
-//    fwprintf(stdout, L"TEST serial port.\n");
+    fwprintf(stdout, L"TEST serial port.\n");
 
-//    test_serial_port_temperature();
-//    test_serial_port_sleep();
+    test_serial_port_temperature();
+    test_serial_port_sleep();
 }
 
 /* SERIAL_PORT_TESTER */
